==> pointpos_api-0.0.16.tar.gz: lib/model/item.dart <==
import 'package:jaguar_serializer/jaguar_serializer.dart';


import 'package:pointpos_api/model/image.dart';

import 'package:pointpos_api/model/item_cost_of_goods_sold.dart';

import 'package:pointpos_api/model/item_variants.dart';

import 'package:pointpos_api/model/item_inventory.dart';

part 'item.jser.dart';

class Item {
  
  @Alias('id', isNullable: false,  )
  final String id;
  
  @Alias('name', isNullable: false,  )
  final String name;
  
  @Alias('categoryId', isNullable: false,  )
  final num categoryId;
  
  @Alias('outletId', isNullable: false,  )
  final String outletId;
  
  @Alias('images', isNullable: false,  )
  final List<Image> images;
  
  @Alias('variants', isNullable: false,  )
  final List<ItemVariants> variants;
  
  @Alias('inventory', isNullable: false,  )
  final List<ItemInventory> inventory;
  
  @Alias('costOfGoodsSold', isNullable: false,  )
  final List<ItemCostOfGoodsSold> costOfGoodsSold;
  
  @Alias('description', isNullable: false,  )
  final String description;
  

  Item(
      

{
     this.id = null,  
    
     this.name = null,  
     this.categoryId = null,   this.outletId = null,  
     this.images = const [],  
    
     this.variants = const [],  
     this.inventory = const [],  
     this.costOfGoodsSold = const [],   this.description = null 
    
    }
  );

  @override
  String toString() {
    return 'Item[id=$id, name=$name, categoryId=$categoryId, outletId=$outletId, images=$images, variants=$variants, inventory=$inventory, costOfGoodsSold=$costOfGoodsSold, description=$description, ]';
  }
}

@GenSerializer(nullableFields: true)
class ItemSerializer extends Serializer<Item> with _$ItemSerializer {

}

==> pointpos_api-0.2.0.tar.gz: lib/model/item.dart <==
import 'package:jaguar_serializer/jaguar_serializer.dart';


import 'package:pointpos_api/model/image.dart';

import 'package:pointpos_api/model/item_cost_of_goods_sold.dart';

import 'package:pointpos_api/model/item_variants.dart';

import 'package:pointpos_api/model/item_inventory.dart';

part 'item.jser.dart';

class Item {
  
  @Alias('id', isNullable: false,  )
  final String id;
  
  @Alias('name', isNullable: false,  )
  final String name;
  
  @Alias('categoryId', isNullable: false,  )
  final num categoryId;
  
  @Alias('outletId', isNullable: false,  )
  final String outletId;
  
  @Alias('images', isNullable: false,  )
  final List<Image> images;
  
  @Alias('variants', isNullable: false,  )
  final List<ItemVariants> variants;
  
  @Alias('inventory', isNullable: false,  )
  final List<ItemInventory> inventory;
  
  @Alias('costOfGoodsSold', isNullable: false,  )
  final List<ItemCostOfGoodsSold> costOfGoodsSold;
  
  @Alias('description', isNullable: false,  )
  final String description;
  
  @Alias('createdAt', isNullable: false,  )
  final DateTime createdAt;
  
  @Alias('createdBy', isNullable: false,  )
  final String createdBy;
  
  @Alias('updatedAt', isNullable: false,  )
  final DateTime updatedAt;
  
  @Alias('updatedBy', isNullable: false,  )
  final String updatedBy;
  
  @Alias('deleted', isNullable: false,  )
  final bool deleted;
  

  Item(
      

{
     this.id = null,  
    
     this.name = null,  
     this.categoryId = null,   this.outletId = null,  
     this.images = const [],  
    
     this.variants = const [],  
     this.inventory = const [],  
     this.costOfGoodsSold = const [],   this.description = null,  
     this.createdAt = null,  
     this.createdBy = null,  
     this.updatedAt = null,  
     this.updatedBy = null,  
     this.deleted = null 
    
    }
  );

  @override
  String toString() {
    return 'Item[id=$id, name=$name, categoryId=$categoryId, outletId=$outletId, images=$images, variants=$variants, inventory=$inventory, costOfGoodsSold=$costOfGoodsSold, description=$description, createdAt=$createdAt, createdBy=$createdBy, updatedAt=$updatedAt, updatedBy=$updatedBy, deleted=$deleted, ]';
  }
}

@GenSerializer(nullableFields: true)
class ItemSerializer extends Serializer<Item> with _$ItemSerializer {

}
